@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -139,13 +139,12 @@ extern "C" {
 # include <arm/limits.h>
 #endif
 
-#if defined(MAGICKCORE__OPENCL)
 #if defined(MAGICKCORE_HAVE_CL_CL_H)
 #  include <CL/cl.h>
+#  define MAGICKCORE_OPENCL_SUPPORT  1
 #endif
 #if defined(MAGICKCORE_HAVE_OPENCL_CL_H)
 #  include <OpenCL/cl.h>
-#endif
 #  define MAGICKCORE_OPENCL_SUPPORT  1
 #endif
 
@@ -175,9 +174,6 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
 #if defined(MAGICKCORE_WINDOWS_SUPPORT) || defined(MAGICKCORE_POSIX_SUPPORT)
 # include <sys/types.h>
 # include <sys/stat.h>
-# if defined(MAGICKCORE_HAVE_SYS_TIMEB_H)
-# include <sys/timeb.h>
-# endif
 # if defined(MAGICKCORE_POSIX_SUPPORT)
 #  if defined(MAGICKCORE_HAVE_SYS_NDIR_H) || defined(MAGICKCORE_HAVE_SYS_DIR_H) || defined(MAGICKCORE_HAVE_NDIR_H)
 #   define dirent direct
@@ -229,13 +225,6 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
 #else
 # include <types.h>
 # include <stat.h>
-# if defined(macintosh)
-#  if !defined(DISABLE_SIOUX)
-#   include <SIOUX.h>
-#   include <console.h>
-#  endif
-#  include <unix.h>
-# endif
 # include "MagickCore/magick-type.h"
 #endif
 
@@ -315,9 +304,6 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
 #  define SetNotifyHandlers \
     SetErrorHandler(NTErrorHandler); \
     SetWarningHandler(NTWarningHandler)
-#  if !defined(MAGICKCORE_HAVE_TIFFCONF_H)
-#    define HAVE_TIFFCONF_H
-#  endif
 # endif
 
 #endif
@@ -350,6 +336,8 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
   Magick defines.
 */
 #define MagickMaxRecursionDepth  600
+#define MAGICK_SSIZE_MAX  (SSIZE_MAX)
+#define MAGICK_SSIZE_MIN  (-(SSIZE_MAX)-1)
 #define Swap(x,y) ((x)^=(y), (y)^=(x), (x)^=(y))
 #if defined(_MSC_VER)
 # define DisableMSCWarning(nr) __pragma(warning(push)) \
